Struct LnUrlPayRequestData
pub struct LnUrlPayRequestData {
pub callback: String,
pub min_sendable: u64,
pub max_sendable: u64,
pub metadata_str: String,
pub comment_allowed: u16,
pub domain: String,
pub allows_nostr: bool,
pub nostr_pubkey: Option<String>,
pub ln_address: Option<String>,
}Expand description
Wrapped in a [LnUrlPay], this is the result of parse when given a LNURL-pay endpoint.
It represents the endpoint’s parameters for the LNURL workflow.
Fields
callback: Stringmin_sendable: u64The minimum amount, in millisats, that this LNURL-pay endpoint accepts
max_sendable: u64The maximum amount, in millisats, that this LNURL-pay endpoint accepts
metadata_str: StringAs per LUD-06, metadata is a raw string (e.g. a json representation of the inner map).
Use metadata_vec() to get the parsed items.
comment_allowed: u16The comment length accepted by this endpoint
domain: StringIndicates the domain of the LNURL-pay service, to be shown to the user when asking for payment input, as per LUD-06 spec.
Note: this is not the domain of the callback, but the domain of the LNURL-pay endpoint.
allows_nostr: boolValue indicating whether the recipient supports Nostr Zaps through NIP-57.
See https://github.com/nostr-protocol/nips/blob/master/57.md
nostr_pubkey: Option<String>Optional recipient’s lnurl provider’s Nostr pubkey for NIP-57. If it exists it should be a valid BIP 340 public key in hex.
See https://github.com/nostr-protocol/nips/blob/master/57.md See https://github.com/bitcoin/bips/blob/master/bip-0340.mediawiki
ln_address: Option<String>If sending to a LN Address, this will be filled.
Implementations
impl LnUrlPayRequestData
impl LnUrlPayRequestData
pub fn min_sendable_sats(&self) -> u64
pub fn min_sendable_sats(&self) -> u64
The minimum amount, in sats, accepted by this LNURL-pay endpoint
pub fn max_sendable_sats(&self) -> u64
pub fn max_sendable_sats(&self) -> u64
The maximum amount, in sats, accepted by this LNURL-pay endpoint
pub fn metadata_vec(&self) -> Result<Vec<MetadataItem>, Error>
pub fn metadata_vec(&self) -> Result<Vec<MetadataItem>, Error>
Parsed metadata items. Use metadata_str to get the raw metadata string, as received from
the LNURL endpoint.